aboutsummaryrefslogtreecommitdiff
path: root/bpkg/rep-fetch.hxx
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2022-07-29 17:37:33 +0300
committerKaren Arutyunov <karen@codesynthesis.com>2022-08-02 14:26:28 +0300
commitd6d72bc6e4545d216d89660f86781bbc34980fe9 (patch)
tree2971fda1501575cdc493095fecd1a8e5c0af9668 /bpkg/rep-fetch.hxx
parentfee16e0139803510bb0666aa56990af5849b0589 (diff)
For rep-create, pkg-verify, and rep-info don't verify build-time toolchain dependency constraints if --ignore-unknown option is specified
Diffstat (limited to 'bpkg/rep-fetch.hxx')
-rw-r--r--bpkg/rep-fetch.hxx20
1 files changed, 12 insertions, 8 deletions
diff --git a/bpkg/rep-fetch.hxx b/bpkg/rep-fetch.hxx
index 7e03999..a26eba3 100644
--- a/bpkg/rep-fetch.hxx
+++ b/bpkg/rep-fetch.hxx
@@ -37,7 +37,8 @@ namespace bpkg
// Empty if the build2 project info is not available for the packages.
// Currently we only retrieve it for the directory and version control
- // based repositories.
+ // based repositories, but only if the current build2 version is
+ // satisfactory for all the repository packages.
//
vector<package_info> package_infos;
};
@@ -50,19 +51,22 @@ namespace bpkg
shared_ptr<const bpkg::certificate> certificate; // Authenticated.
};
// If requested, expand the file-referencing package manifest values
// (description, changes, etc), setting them to the contents of files they
// refer to and set the potentially absent description-type value to the
// effective description type (see libbpkg/manifest.hxx) and load the
// bootstrap, root, and config/*.build buildfiles into the respective *-build
// values. Note that for pkg repositories such values are expanded/loaded at
// the repository creation time.
//
rep_fetch_data
rep_fetch (const common_options&,
const dir_path* configuration,
const repository_location&,
bool ignore_unknown,
+ bool ignore_toolchain,
bool expand_values,
bool load_buildfiles);
@@ -50,19 +51,22 @@ namespace bpkg
shared_ptr<const bpkg::certificate> certificate; // Authenticated.
};
- // If requested, expand the file-referencing package manifest values
- // (description, changes, etc), setting them to the contents of files they
- // refer to and set the potentially absent description-type value to the
- // effective description type (see libbpkg/manifest.hxx) and load the
- // bootstrap, root, and config/*.build buildfiles into the respective *-build
- // values. Note that for pkg repositories such values are expanded/loaded at
- // the repository creation time.
+ // If requested, verify that all manifest entries are recognized and the
+ // packages are compatible with the current toolchain. Also, if requested,
+ // expand the file-referencing package manifest values (description,
+ // changes, etc), setting them to the contents of files they refer to and
+ // set the potentially absent description-type value to the effective
+ // description type (see libbpkg/manifest.hxx) and load the bootstrap, root,
+ // and config/*.build buildfiles into the respective *-build values. Note
+ // that for pkg repositories such values are expanded/loaded at the
+ // repository creation time.
//
rep_fetch_data